@@ -13,4 +13,4 @@
 # See the Licence for the specific language governing permissions and
 # limitations under the Licence, but note it is strictly for non-commercial use.
 """Module for conversion between Google Cirq and :math:`\\mathrm{t|ket}\\rangle` primitives."""
-from .cirq_convert import cirq_to_tk, tk_to_cirq, process_device
+from .cirq_convert import cirq_to_tk, tk_to_cirq, process_characterisation
